@@ -13,9 +13,6 @@ from .charts import *
 
 
 def backtest(
-    address: str,
-    startfrom: int,
-    network: int,
     range_min: float,
     range_max: float,
     target: float,
