@@ -84,17 +84,17 @@ def chart1(dpd, base, myliquidity, verbose):
             "---------------------------------- Backtest -----------------------------------"
         )
         print(
-            "LP position returned:",
+            "(Bounded) LP position returned:",
             df_1["feeV"].sum() / df_1["amountV"].iloc[0] * 100,
-            "in",
+            "% in",
             len(df_1.index),
             "days, for an APR of",
             df_1["feeV"].sum() / df_1["amountV"].iloc[0] * 365 / len(df_1.index) * 100,
         )
         print(
-            "Base  position returned:",
+            "(Unbounded) LP  position returned:",
             df_1["feeunb"].sum() / df_1["amountV"].iloc[0] * 100,
-            "in",
+            "% in",
             len(df_1.index),
             "days, for an APR of",
             df_1["feeunb"].sum()
